@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -41,23 +41,24 @@
 #define JUCE_EVENTS_INCLUDE_WIN32_MESSAGE_WINDOW 1
 #define JUCE_GRAPHICS_INCLUDE_COREGRAPHICS_HELPERS 1
 #define JUCE_GUI_BASICS_INCLUDE_XHEADERS 1
+#define JUCE_GUI_BASICS_INCLUDE_SCOPED_THREAD_DPI_AWARENESS_SETTER 1
 
 #include "juce_gui_basics.h"
 
+#include <cctype>
+
 //==============================================================================
 #if JUCE_MAC
  #import <WebKit/WebKit.h>
  #import <IOKit/pwr_mgt/IOPMLib.h>
-
- #if JUCE_SUPPORT_CARBON
-  #import <Carbon/Carbon.h> // still needed for SetSystemUIMode()
- #endif
+ #import <MetalKit/MetalKit.h>
 
 #elif JUCE_IOS
  #if JUCE_PUSH_NOTIFICATIONS && defined (__IPHONE_10_0) && __IPHONE_OS_VERSION_MAX_ALLOWED >= __IPHONE_10_0
   #import <UserNotifications/UserNotifications.h>
  #endif
 
+ #import <MetalKit/MetalKit.h>
  #import <UIKit/UIActivityViewController.h>
 
 //==============================================================================
@@ -65,6 +66,13 @@
  #include <windowsx.h>
  #include <vfw.h>
  #include <commdlg.h>
+ #include <commctrl.h>
+ #include <sapi.h>
+
+ #if JUCE_MSVC
+  #include <Dxgi.h>
+  #include <UIAutomation.h>
+ #endif
 
  #if JUCE_WEB_BROWSER
   #include <exdisp.h>
@@ -76,6 +84,8 @@
  #elif ! JUCE_DONT_AUTOLINK_TO_WIN32_LIBRARIES
   #pragma comment(lib, "vfw32.lib")
   #pragma comment(lib, "imm32.lib")
+  #pragma comment(lib, "comctl32.lib")
+  #pragma comment(lib, "dxgi.lib")
 
   #if JUCE_OPENGL
    #pragma comment(lib, "OpenGL32.Lib")
@@ -89,8 +99,6 @@
  #endif
 #endif
 
-#include <set>
-
 //==============================================================================
 #define JUCE_ASSERT_MESSAGE_MANAGER_IS_LOCKED_OR_OFFSCREEN \
     jassert ((MessageManager::getInstanceWithoutCreating() != nullptr \
@@ -99,18 +107,43 @@
 
 namespace juce
 {
-    extern bool juce_areThereAnyAlwaysOnTopWindows();
-}
+    bool juce_areThereAnyAlwaysOnTopWindows();
 
+    bool isEmbeddedInForegroundProcess (Component* c);
+
+   #if ! JUCE_WINDOWS
+    bool isEmbeddedInForegroundProcess (Component*) { return false; }
+   #endif
+
+    /*  Returns true if this process is in the foreground, or if the viewComponent
+        is embedded into a window owned by the foreground process.
+    */
+    static bool isForegroundOrEmbeddedProcess (Component* viewComponent)
+    {
+        return Process::isForegroundProcess() || isEmbeddedInForegroundProcess (viewComponent);
+    }
+
+    bool isWindowOnCurrentVirtualDesktop (void*);
+
+    struct CustomMouseCursorInfo
+    {
+        ScaledImage image;
+        Point<int> hotspot;
+    };
+} // namespace juce
+
+#include "mouse/juce_PointerState.h"
+
+#include "accessibility/juce_AccessibilityHandler.cpp"
 #include "components/juce_Component.cpp"
 #include "components/juce_ComponentListener.cpp"
+#include "components/juce_FocusTraverser.cpp"
 #include "mouse/juce_MouseInputSource.cpp"
 #include "desktop/juce_Displays.cpp"
 #include "desktop/juce_Desktop.cpp"
 #include "components/juce_ModalComponentManager.cpp"
 #include "mouse/juce_ComponentDragger.cpp"
 #include "mouse/juce_DragAndDropContainer.cpp"
-#include "mouse/juce_MouseCursor.cpp"
 #include "mouse/juce_MouseEvent.cpp"
 #include "mouse/juce_MouseInactivityDetector.cpp"
 #include "mouse/juce_MouseListener.cpp"
@@ -218,6 +251,7 @@ namespace juce
 #include "application/juce_Application.cpp"
 #include "misc/juce_BubbleComponent.cpp"
 #include "misc/juce_DropShadower.cpp"
+#include "misc/juce_FocusOutline.cpp"
 
 #include "layout/juce_FlexBox.cpp"
 #include "layout/juce_GridItem.cpp"
@@ -227,10 +261,15 @@ namespace juce
  #include "native/juce_MultiTouchMapper.h"
 #endif
 
+#if JUCE_ANDROID || JUCE_WINDOWS || JUCE_UNIT_TESTS
+ #include "native/accessibility/juce_AccessibilityTextHelpers.h"
+#endif
+
 #if JUCE_MAC || JUCE_IOS
- JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wundeclared-selector")
+ #include "native/accessibility/juce_mac_AccessibilitySharedCode.mm"
 
  #if JUCE_IOS
+  #include "native/accessibility/juce_ios_Accessibility.mm"
   #include "native/juce_ios_UIViewComponentPeer.mm"
   #include "native/juce_ios_Windowing.mm"
   #include "native/juce_ios_FileChooser.mm"
@@ -240,22 +279,30 @@ namespace juce
   #endif
 
  #else
+  #include "native/accessibility/juce_mac_Accessibility.mm"
   #include "native/juce_mac_NSViewComponentPeer.mm"
   #include "native/juce_mac_Windowing.mm"
   #include "native/juce_mac_MainMenu.mm"
   #include "native/juce_mac_FileChooser.mm"
  #endif
 
- JUCE_END_IGNORE_WARNINGS_GCC_LIKE
-
  #include "native/juce_mac_MouseCursor.mm"
 
 #elif JUCE_WINDOWS
+ #if JUCE_MSVC
+  #include "native/accessibility/juce_win32_ComInterfaces.h"
+  #include "native/accessibility/juce_win32_WindowsUIAWrapper.h"
+  #include "native/accessibility/juce_win32_AccessibilityElement.h"
+  #include "native/accessibility/juce_win32_UIAHelpers.h"
+  #include "native/accessibility/juce_win32_UIAProviders.h"
+  #include "native/accessibility/juce_win32_AccessibilityElement.cpp"
+  #include "native/accessibility/juce_win32_Accessibility.cpp"
+ #endif
  #include "native/juce_win32_Windowing.cpp"
  #include "native/juce_win32_DragAndDrop.cpp"
  #include "native/juce_win32_FileChooser.cpp"
 
-#elif JUCE_LINUX
+#elif JUCE_LINUX || JUCE_BSD
  #include "native/x11/juce_linux_X11_Symbols.cpp"
  #include "native/x11/juce_linux_X11_DragAndDrop.cpp"
 
@@ -269,8 +316,9 @@ namespace juce
  #include "native/juce_linux_FileChooser.cpp"
 
 #elif JUCE_ANDROID
+ #include "juce_core/files/juce_common_MimeTypes.h"
+ #include "native/accessibility/juce_android_Accessibility.cpp"
  #include "native/juce_android_Windowing.cpp"
- #include "native/juce_common_MimeTypes.cpp"
  #include "native/juce_android_FileChooser.cpp"
 
  #if JUCE_CONTENT_SHARING
@@ -278,3 +326,94 @@ namespace juce
  #endif
 
 #endif
+
+namespace juce
+{
+   #if ! JUCE_NATIVE_ACCESSIBILITY_INCLUDED
+    class AccessibilityHandler::AccessibilityNativeImpl { public: AccessibilityNativeImpl (AccessibilityHandler&) {} };
+    void AccessibilityHandler::notifyAccessibilityEvent (AccessibilityEvent) const {}
+    void AccessibilityHandler::postAnnouncement (const String&, AnnouncementPriority) {}
+    AccessibilityNativeHandle* AccessibilityHandler::getNativeImplementation() const { return nullptr; }
+    void notifyAccessibilityEventInternal (const AccessibilityHandler&, InternalAccessibilityEvent) {}
+    std::unique_ptr<AccessibilityHandler::AccessibilityNativeImpl> AccessibilityHandler::createNativeImpl (AccessibilityHandler&)
+    {
+        return nullptr;
+    }
+   #else
+    std::unique_ptr<AccessibilityHandler::AccessibilityNativeImpl> AccessibilityHandler::createNativeImpl (AccessibilityHandler& handler)
+    {
+        return std::make_unique<AccessibilityNativeImpl> (handler);
+    }
+   #endif
+}
+
+//==============================================================================
+#if JUCE_WINDOWS
+namespace juce
+{
+
+JUCE_COMCLASS (JuceIVirtualDesktopManager, "a5cd92ff-29be-454c-8d04-d82879fb3f1b") : public IUnknown
+{
+public:
+    virtual HRESULT STDMETHODCALLTYPE IsWindowOnCurrentVirtualDesktop(
+         __RPC__in HWND topLevelWindow,
+         __RPC__out BOOL * onCurrentDesktop) = 0;
+
+    virtual HRESULT STDMETHODCALLTYPE GetWindowDesktopId(
+         __RPC__in HWND topLevelWindow,
+         __RPC__out GUID * desktopId) = 0;
+
+    virtual HRESULT STDMETHODCALLTYPE MoveWindowToDesktop(
+         __RPC__in HWND topLevelWindow,
+         __RPC__in REFGUID desktopId) = 0;
+};
+
+JUCE_COMCLASS (JuceVirtualDesktopManager, "aa509086-5ca9-4c25-8f95-589d3c07b48a");
+
+} // namespace juce
+
+#ifdef __CRT_UUID_DECL
+__CRT_UUID_DECL (juce::JuceIVirtualDesktopManager, 0xa5cd92ff, 0x29be, 0x454c, 0x8d, 0x04, 0xd8, 0x28, 0x79, 0xfb, 0x3f, 0x1b)
+__CRT_UUID_DECL (juce::JuceVirtualDesktopManager,  0xaa509086, 0x5ca9, 0x4c25, 0x8f, 0x95, 0x58, 0x9d, 0x3c, 0x07, 0xb4, 0x8a)
+#endif
+
+bool juce::isWindowOnCurrentVirtualDesktop (void* x)
+{
+    if (x == nullptr)
+        return false;
+
+    static auto* desktopManager = []
+    {
+        JuceIVirtualDesktopManager* result = nullptr;
+
+        JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wlanguage-extension-token")
+
+        if (SUCCEEDED (CoCreateInstance (__uuidof (JuceVirtualDesktopManager), nullptr, CLSCTX_ALL, IID_PPV_ARGS (&result))))
+            return result;
+
+        JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+
+        return static_cast<JuceIVirtualDesktopManager*> (nullptr);
+    }();
+
+    BOOL current = false;
+
+    if (auto* dm = desktopManager)
+        if (SUCCEEDED (dm->IsWindowOnCurrentVirtualDesktop (static_cast<HWND> (x), &current)))
+            return current != false;
+
+    return true;
+}
+
+#else
+ bool juce::isWindowOnCurrentVirtualDesktop (void*) { return true; }
+ juce::ScopedDPIAwarenessDisabler::ScopedDPIAwarenessDisabler()  { ignoreUnused (previousContext); }
+ juce::ScopedDPIAwarenessDisabler::~ScopedDPIAwarenessDisabler() {}
+#endif
+
+// Depends on types defined in platform-specific windowing files
+#include "mouse/juce_MouseCursor.cpp"
+
+#if JUCE_UNIT_TESTS
+#include "native/accessibility/juce_AccessibilityTextHelpers_test.cpp"
+#endif
