@@ -3,7 +3,7 @@
 
    This file is part of the Water library.
    Copyright (c) 2016 ROLI Ltd.
-   Copyright (C) 2018 Filipe Coelho <falktx@falktx.com>
+   Copyright (C) 2018-2022 Filipe Coelho <falktx@falktx.com>
 
    Permission is granted to use this software under the terms of the ISC license
    http://www.isc.org/downloads/software-support-policy/isc-license/
@@ -331,7 +331,7 @@ private:
         ValueType value;
         HashEntry* nextEntry;
 
-        CARLA_DECLARE_NON_COPY_CLASS (HashEntry)
+        CARLA_DECLARE_NON_COPYABLE (HashEntry)
     };
 
 public:
