@@ -1,7 +1,7 @@
 /*
  * Carla Style, based on Qt5 fusion style
  * Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies)
- * Copyright (C) 2013-2019 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2013-2022 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,7 +40,7 @@ Q_EXPORT_PLUGIN2(Carla, CarlaStylePlugin)
 #endif
 
 #ifdef CARLA_OS_WIN
-CARLA_EXPORT void set_qt_app_style()
+CARLA_PLUGIN_EXPORT void set_qt_app_style()
 {
     qApp->setStyle(new CarlaStyle());
 }
