@@ -1,6 +1,6 @@
 /*
  * Carla Pipe Utilities
- * Copyright (C) 2013-2019 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2013-2022 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -632,7 +632,7 @@ struct CarlaPipeCommon::PrivateData {
         carla_zeroChars(tmpBuf, 0xffff);
     }
 
-    CARLA_DECLARE_NON_COPY_STRUCT(PrivateData)
+    CARLA_DECLARE_NON_COPYABLE(PrivateData)
 };
 
 // -----------------------------------------------------------------------
