@@ -1,6 +1,6 @@
 /*
  * Carla Plugin UI
- * Copyright (C) 2014-2021 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2014-2022 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,6 +19,7 @@
 #include "CarlaPluginUI.hpp"
 
 #ifdef HAVE_X11
+# include <pthread.h>
 # include <sys/types.h>
 # include <X11/Xatom.h>
 # include <X11/Xlib.h>
@@ -1164,7 +1165,7 @@ bool CarlaPluginUI::tryTransientWinIdMatch(const uintptr_t pid, const char* cons
         ~ScopedDisplay() { if (display!=nullptr) XCloseDisplay(display); }
         // c++ compat stuff
         CARLA_PREVENT_HEAP_ALLOCATION
-        CARLA_DECLARE_NON_COPY_CLASS(ScopedDisplay)
+        CARLA_DECLARE_NON_COPYABLE(ScopedDisplay)
     };
     struct ScopedFreeData {
         union {
@@ -1176,7 +1177,7 @@ bool CarlaPluginUI::tryTransientWinIdMatch(const uintptr_t pid, const char* cons
         ~ScopedFreeData() { XFree(data); }
         // c++ compat stuff
         CARLA_PREVENT_HEAP_ALLOCATION
-        CARLA_DECLARE_NON_COPY_CLASS(ScopedFreeData)
+        CARLA_DECLARE_NON_COPYABLE(ScopedFreeData)
     };
 
     const ScopedDisplay sd;
